@@ -136,7 +136,9 @@ def write_dbc_cmd(json_file: str, dbc: str):
 @click.argument("skel")
 @click.option("--noformat", is_flag=True, default=False)
 @click.option("--force", is_flag=True, default=False)
-def c_gen_cmd(templates: str, output: str, json_file: str, skel: str, noformat: bool, force: bool):
+def c_gen_cmd(
+    templates: str, output: str, json_file: str, skel: str, noformat: bool, force: bool
+):
     """Transform FCP json into a C library.
     :param templates: jinja template directory.
     :param output: output directory.
@@ -200,151 +202,6 @@ def gui_cmd(file: str):
     gui(file)
 
 
-@click.command(name="gui2")
-@click.argument("file", type=Path, required=False)
-def gui_cmd2(file: Path):
-    """Launch FCP json editor GUI.
-    :param file: Optional FCP json file path
-    """
-
-    from .gui2 import gui2
-
-    gui2(file)
-
-
-@click.command()
-@click.argument("json_file")
-def dump_dev_list(json_file):
-    spec = get_spec(json_file)
-
-    for dev in spec.devices.keys():
-        print(dev)
-
-
-@click.command()
-@click.argument("json_file")
-@click.argument("device", required=False)
-def dump_msg_list(json_file, device):
-    spec = get_spec(json_file)
-
-    for dev_name, dev in spec.devices.items():
-        if device != None and device != dev_name:
-            continue
-
-        for msg in dev.msgs.keys():
-            print(msg)
-
-
-@click.command()
-@click.argument("json_file")
-@click.argument("device", required=False)
-def dump_cfg_list(json_file, device):
-    spec = get_spec(json_file)
-
-    for dev_name, dev in spec.devices.items():
-        if device != None and device != dev_name:
-            continue
-
-        for cfg in dev.cfgs.keys():
-            print(cfg)
-
-
-@click.command()
-@click.argument("json_file")
-@click.argument("device", required=False)
-def dump_cmd_list(json_file, device):
-    spec = get_spec(json_file)
-
-    for dev_name, dev in spec.devices.items():
-        if device != None and device != dev_name:
-            continue
-
-        for cmd in dev.cmds.keys():
-            print(cmd)
-
-
-@click.command()
-@click.argument("json_file")
-def dump_log_list(json_file):
-    spec = get_spec(json_file)
-
-    for log in spec.logs.keys():
-        print(log)
-
-
-@click.command()
-@click.argument("json_file")
-@click.argument("message", required=False)
-def dump_signal_list(json_file, message):
-    spec = get_spec(json_file)
-
-    for dev in spec.devices.values():
-        for msg in dev.msgs.values():
-            if message != None and msg.name != message:
-                continue
-            for signal in msg.signals.values():
-                print(signal)
-
-
-@click.command()
-@click.argument("json_file")
-@click.argument("message", required=False)
-def dump_signal_names(json_file, message):
-    spec = get_spec(json_file)
-
-    for dev in spec.devices.values():
-        for msg in dev.msgs.values():
-            if message != None and msg.name != message:
-                continue
-            for signal in msg.signals.values():
-                print(signal.name)
-
-
-@click.command()
-@click.argument("json_file")
-@click.argument("log")
-def print_log(json_file, log):
-    spec = get_spec(json_file)
-
-    print(spec.get_log(log))
-
-
-@click.command()
-@click.argument("json_file")
-@click.argument("dev")
-def print_dev(json_file, dev):
-    spec = get_spec(json_file)
-
-    print(spec.get_device(dev))
-
-
-@click.command()
-@click.argument("json_file")
-@click.argument("message")
-def print_msg(json_file, message):
-    spec = get_spec(json_file)
-
-    for dev in spec.devices.values():
-        for name, msg in dev.msgs.items():
-            if name == message:
-                print(dev.name)
-                print(msg)
-
-
-@click.command()
-@click.argument("json_file")
-@click.argument("signal")
-def print_signal(json_file, signal):
-    spec = get_spec(json_file)
-
-    for dev in spec.devices.values():
-        for msg in dev.msgs.values():
-            for name, sig in msg.signals.items():
-                if name == signal:
-                    print(dev.name, msg.name)
-                    print(sig)
-
-
 @click.command("docs")
 @click.argument("json_file")
 @click.argument("out")
@@ -363,6 +220,7 @@ def docs(json_file: str, out: str, link_location: str):
     spec = get_spec(json_file)
     generate_docs(spec, out, link_location, logger)
 
+
 @click.command("fix")
 @click.argument("src")
 @click.argument("dst")
@@ -380,11 +238,11 @@ def fix(src: str, dst: str):
                 if sig.mux_count == 0:
                     sig.mux_count = 1
 
-
     d = spec.compile()
     with open(dst, "w") as f:
         f.write(json.dumps(d, indent=4))
 
+
 @click.command("json_to_fcp2")
 @click.argument("json_file")
 @click.argument("output")
@@ -396,31 +254,19 @@ def json_to_fcp2(json_file: str, output: str):
         f.write(v2)
 
 
-
-@click.command("read_fcp2")
-@click.argument("fcp_v2_file")
-def read_fcp2(fcp_v2_file):
-    with open(fcp_v2_file) as f:
-        v2 = fcp_v2(f.read())
-
-    spec = Spec()
-    spec.decompile(v2)
-
-
-@click.command("read_fcp")
-@click.argument("json_file")
-def read_fcp(json_file: str):
-    logger = setup_logging()
-
-    spec = get_spec(json_file)
-    print(spec)
-
+@click.command("fcp2_to_json")
+@click.argument("fcpv2")
+@click.argument("fcpv1")
+def fcp2_to_json(fcpv2: str, fcpv1: str):
+    spec = get_spec(fcpv2)
+    with open(fcpv1, "w") as f:
+        f.write(json.dumps(spec.compile(), indent=4))
 
 
 @click.group(invoke_without_command=True)
 @click.option("--version", is_flag=True, default=False)
 def main(version):
-    """CLI utility for managment of FCP JSON files. """
+    """CLI utility for managment of FCP JSON files."""
 
     if len(sys.argv) == 1:
         print("fcp cli util.\nVersion:", VERSION, "\nFor usage see fcp --help")
@@ -435,22 +281,10 @@ main.add_command(c_gen_cmd)
 main.add_command(init_cmd)
 main.add_command(validate_cmd)
 main.add_command(gui_cmd)
-#main.add_command(dump_dev_list)
-#main.add_command(dump_msg_list)
-#main.add_command(dump_cfg_list)
-#main.add_command(dump_cmd_list)
-#main.add_command(dump_log_list)
-#main.add_command(dump_signal_list)
-#main.add_command(dump_signal_names)
-#main.add_command(print_log)
-#main.add_command(print_dev)
-#main.add_command(print_msg)
-#main.add_command(print_signal)
 main.add_command(docs)
 main.add_command(fix)
 main.add_command(json_to_fcp2)
-main.add_command(read_fcp2)
-main.add_command(read_fcp)
+main.add_command(fcp2_to_json)
 
 if __name__ == "__main__":
     main()
