@@ -2,7 +2,8 @@ from PySide2.QtWidgets import *
 from PySide2.QtGui import QKeySequence
 from PySide2.QtCore import Qt
 
-class MessageBox():
+
+class MessageBox:
     def __init__(self, parent, buttons, icon, text):
         self.msg = QMessageBox(parent)
         self.msg.setStandardButtons(buttons)
@@ -11,4 +12,3 @@ class MessageBox():
 
     def launch(self):
         self.msg.show()
-
